************************************************************
	*Title of dofile: WDR2020_chapter2_countryreg_main.do 
	*Authors: Ana Fernandes (afernandes@worldbank.org), Hiau Looi Kee (hlkee@worldbank.org), and Deborah Winkler (dwinkler2@worldbank.org)
	*This version: October 2019
	*This do file generates the country dataset collapsed by decade and runs between-effects regressions to estimate determinants of GVC participation - main results
	*for chapter 2 of the World Development Report 2020.
	*Please cite World Development Report 2020: Trading for Development in the Age of Global Value Chains. Washington, DC: World Bank.				
************************************************************
				

************************************************************				
***DETERMINANTS OF GVC PARTICIPATION***
************************************************************	
	
clear all
set more off

use "WDR2020_chapter2_countryreg.dta", clear 

egen c=group(iso)
gen decade=(year<2000)
replace decade=2 if year>=2000 & year<2010
replace decade=3 if year>=2010

* generate Pol's suggested measures of endowments using real GDP as denominator
gen lnrkna_GDP=ln(rkna/(exp(lnrgdp)))
gen lnland_GDP=ln(land/(exp(lnrgdp)))
gen lnlowskill_GDP=ln(emp_ls/(exp(lnrgdp)))
gen lnmedhighskill_GDP=ln((emp_hs+emp_ms)/(exp(lnrgdp))) 
gen lnhighskill_GDP=ln((emp_hs)/(exp(lnrgdp))) 

** generate size of manufacturing sector (market size effects for suppliers)
gen lnvamfg=ln(exp(lnngdp)*va_mfg/100)

** generate labor cost - Kee variables 
gen llaborcost=ln((ngdp*labsh/emp))
gen unitlaborcost=rwage/lp_2011
gen lunitlaborcost=ln(unitlaborcost)

** generate distance to 3 GVC hubs
gen lnsumdist=ln(distcapCHN+distcapDEU+distcapUSA)

** generate appreciation rate (>0 is appreciation)
gen ioer=1/oer
by iso: gen appioer=ioer-ioer[_n-1] if year-year[_n-1]==1

* gen logs of trade agreement variables 
gen lnnb_PTApartners=ln(nb_PTApartners)
gen llaborcost_deflated=ln((ngdp*labsh/emp)*(rgdp/ngdp))

egen region2=group(region)
gen high_income=(income=="H")
				 
* some measures collapsed here are not used for baseline regressions in this do-file 
collapse (mean) gvcebsh_EORA gvcebsh_TIVA16 gvcebsh_TIVA18 gvcebsh_WIOD13 gvcebsh_WIOD16 gvcobsh_EORA gvcobsh_TIVA16 gvcobsh_TIVA18 gvcobsh_WIOD13 gvcobsh_WIOD16 iiimports_out_EORA gvcefsh_EORA gvcefsh_TIVA16 gvcefsh_TIVA18 gvcefsh_WIOD13 gvcefsh_WIOD16 gvcofsh_EORA gvcofsh_TIVA16 gvcofsh_TIVA18 gvcofsh_WIOD13  gvcofsh_WIOD16 iiexports_out_EORA gvcesh_EORA gvcesh_TIVA18 gvcesh_TIVA16 gvcesh_WIOD13 gvcesh_WIOD16 gvcosh_EORA gvcosh_TIVA18 gvcosh_TIVA16 gvcosh_WIOD13 gvcosh_WIOD16 tar_wmean_mfg lnfdi_in_flow lnsumdist lnvamfg stability_est rents_resources lnrkna_GDP lnland_GDP lnlowskill_GDP lnmedhighskill_GDP appioer nafta eu mercosur asean lnnb_PTApartners lndepth mis_model1 credit high_income time_im0615 lpi_over_sc f_t_lfpr internet_use english_spoken llaborcost_deflated lngvceb_EORA lngvcef_EORA lngvcob_EORA lngvcof_EORA lngvce_EORA lngvco_EORA lnexports lnimports gvcebsh_agr_alt gvcebsh_comm_alt gvcebsh_mfg_alt gvcebsh_serv_alt gvcefsh_agr_alt gvcefsh_comm_alt gvcefsh_mfg_alt gvcefsh_serv_alt, by(iso decade)

* generate 1-decade lags of GVC determinants to enter GVC participation regressions
foreach x in tar_wmean_mfg lnfdi_in_flow lnsumdist lnvamfg stability_est rents_resources lnrkna_GDP lnland_GDP lnlowskill_GDP lnmedhighskill_GDP appioer nafta eu mercosur asean lnnb_PTApartners lndepth mis_model1 credit high_income time_im0615 lpi_over_sc f_t_lfpr internet_use english_spoken llaborcost_deflated {
sort iso decade
by iso: gen lag`x'=`x'[_n-1] if decade-decade[_n-1]==1
}

* some countries need to be dropped due to problematic values of their EORA GVC participation measures
drop if iso == "mda" | iso == "mus" | iso == "lbr" | iso == "sdn" | iso == "ssd" | iso == "zwe"


tab decade, gen(dedum)
egen c=group(iso)
xtset c



***************** MEASURES OF GVC PARTICIPATION IN SHARES - COEFFICIENTS AND BETA COEFFICIENTS FOR 2 SPECIFICATIONS SHOWN IN WDR 2020 BOX 2.2
* baseline
xtreg gvcebsh_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer dedum* , be  
outreg2  using "table_backwardforwardshares_country.xls", excel dec(3) append	
gen blagtar_wmean_mfg=_b[lagtar_wmean_mfg]
gen blaglnfdi_in_flow=_b[laglnfdi_in_flow] 
gen blnsumdist=_b[lnsumdist] 
gen blagstability_est=_b[lagstability_est] 
gen blaglnvamfg=_b[laglnvamfg] 
gen blagrents_resources=_b[lagrents_resources] 
gen blaglnland_GDP=_b[laglnland_GDP] 
gen blaglnrkna_GDP=_b[laglnrkna_GDP] 
gen blaglnlowskill_GDP=_b[laglnlowskill_GDP] 
gen blagappioer=_b[lagappioer]
egen sgvcebsh_EORA=sd(gvcebsh_EORA) if e(sample)
egen slagtar_wmean_mfg=sd(lagtar_wmean_mfg) if e(sample)
egen slaglnfdi_in_flow=sd(laglnfdi_in_flow) if e(sample)
egen slnsumdist=sd(lnsumdist) if e(sample)
egen slagstability_est=sd(lagstability_est) if e(sample)
egen slaglnvamfg=sd(laglnvamfg) if e(sample)
egen slagrents_resources=sd(lagrents_resources) if e(sample)
egen slaglnland_GDP=sd(laglnland_GDP) if e(sample) 
egen slaglnrkna_GDP=sd(laglnrkna_GDP) if e(sample) 
egen slaglnlowskill_GDP=sd(laglnlowskill_GDP) if e(sample) 
egen slagappioer=sd(lagappioer) if e(sample)
foreach x in lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnland_GDP  laglnrkna_GDP laglnlowskill_GDP lagappioer {
gen `x'b1=b`x'*(s`x'/sgvcebsh_EORA)
}
drop blag* slag* bln* sln* sgvc* 

* baseline
xtreg gvcefsh_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer dedum* , be  
outreg2  using "table_backwardforwardshares_country.xls", excel dec(3) append	
gen blagtar_wmean_mfg=_b[lagtar_wmean_mfg]
gen blaglnfdi_in_flow=_b[laglnfdi_in_flow] 
gen blnsumdist=_b[lnsumdist] 
gen blagstability_est=_b[lagstability_est] 
gen blaglnvamfg=_b[laglnvamfg] 
gen blagrents_resources=_b[lagrents_resources] 
gen blaglnland_GDP=_b[laglnland_GDP] 
gen blaglnrkna_GDP=_b[laglnrkna_GDP] 
gen blaglnlowskill_GDP=_b[laglnlowskill_GDP] 
gen blagappioer=_b[lagappioer]
egen sgvcefsh_EORA=sd(gvcefsh_EORA) if e(sample)
egen slagtar_wmean_mfg=sd(lagtar_wmean_mfg) if e(sample)
egen slaglnfdi_in_flow=sd(laglnfdi_in_flow) if e(sample)
egen slnsumdist=sd(lnsumdist) if e(sample)
egen slagstability_est=sd(lagstability_est) if e(sample)
egen slaglnvamfg=sd(laglnvamfg) if e(sample)
egen slagrents_resources=sd(lagrents_resources) if e(sample)
egen slaglnland_GDP=sd(laglnland_GDP) if e(sample) 
egen slaglnrkna_GDP=sd(laglnrkna_GDP) if e(sample) 
egen slaglnlowskill_GDP=sd(laglnlowskill_GDP) if e(sample) 
egen slagappioer=sd(lagappioer) if e(sample)
foreach x in lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnland_GDP  laglnrkna_GDP laglnlowskill_GDP lagappioer {
gen `x'b2=b`x'*(s`x'/sgvcefsh_EORA)
}
drop blag* slag* bln* sln* sgvc* 

preserve
collapse (mean) *b1 *b2 
save "betacoefficients_table_backwardforwardshares_country.dta"
restore
drop *b1 *b2


***************** MEASURES OF GVC PARTICIPATION AND TRADE IN LEVELS - TO MENTION IN WDR 2020 BOX 2.2 AND FOR WORKING PAPER (HELPS TO UNDERSTAND SHARES RESULTS ALSO)

* baseline specification used for all levels 
xtreg lngvceb_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnland_GDP  laglnrkna_GDP laglnlowskill_GDP lagappioer dedum* , be  
outreg2  using "table_backwardforwardlevels_country.xls", excel dec(3) append	
gen blagtar_wmean_mfg=_b[lagtar_wmean_mfg]
gen blaglnfdi_in_flow=_b[laglnfdi_in_flow] 
gen blnsumdist=_b[lnsumdist] 
gen blagstability_est=_b[lagstability_est] 
gen blaglnvamfg=_b[laglnvamfg] 
gen blagrents_resources=_b[lagrents_resources] 
gen blaglnland_GDP=_b[laglnland_GDP] 
gen blaglnrkna_GDP=_b[laglnrkna_GDP] 
gen blaglnlowskill_GDP=_b[laglnlowskill_GDP] 
gen blagappioer=_b[lagappioer]
egen slngvceb_EORA=sd(lngvceb_EORA) if e(sample)
egen slagtar_wmean_mfg=sd(lagtar_wmean_mfg) if e(sample)
egen slaglnfdi_in_flow=sd(laglnfdi_in_flow) if e(sample)
egen slnsumdist=sd(lnsumdist) if e(sample)
egen slagstability_est=sd(lagstability_est) if e(sample)
egen slaglnvamfg=sd(laglnvamfg) if e(sample)
egen slagrents_resources=sd(lagrents_resources) if e(sample)
egen slaglnland_GDP=sd(laglnland_GDP) if e(sample) 
egen slaglnrkna_GDP=sd(laglnrkna_GDP) if e(sample) 
egen slaglnlowskill_GDP=sd(laglnlowskill_GDP) if e(sample) 
egen slagappioer=sd(lagappioer) if e(sample)
foreach x in lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnland_GDP  laglnrkna_GDP laglnlowskill_GDP lagappioer {
gen `x'b1=b`x'*(s`x'/slngvceb_EORA)
}
drop blag* slag* bln* sln* slngvc* 

xtreg lngvcob_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnland_GDP  laglnrkna_GDP laglnlowskill_GDP lagappioer dedum* , be  
outreg2  using "table_backwardforwardlevels_country.xls", excel dec(3) append	
gen blagtar_wmean_mfg=_b[lagtar_wmean_mfg]
gen blaglnfdi_in_flow=_b[laglnfdi_in_flow] 
gen blnsumdist=_b[lnsumdist] 
gen blagstability_est=_b[lagstability_est] 
gen blaglnvamfg=_b[laglnvamfg] 
gen blagrents_resources=_b[lagrents_resources] 
gen blaglnland_GDP=_b[laglnland_GDP] 
gen blaglnrkna_GDP=_b[laglnrkna_GDP] 
gen blaglnlowskill_GDP=_b[laglnlowskill_GDP] 
gen blagappioer=_b[lagappioer]
egen slngvcob_EORA=sd(lngvcob_EORA) if e(sample)
egen slagtar_wmean_mfg=sd(lagtar_wmean_mfg) if e(sample)
egen slaglnfdi_in_flow=sd(laglnfdi_in_flow) if e(sample)
egen slnsumdist=sd(lnsumdist) if e(sample)
egen slagstability_est=sd(lagstability_est) if e(sample)
egen slaglnvamfg=sd(laglnvamfg) if e(sample)
egen slagrents_resources=sd(lagrents_resources) if e(sample)
egen slaglnland_GDP=sd(laglnland_GDP) if e(sample) 
egen slaglnrkna_GDP=sd(laglnrkna_GDP) if e(sample) 
egen slaglnlowskill_GDP=sd(laglnlowskill_GDP) if e(sample) 
egen slagappioer=sd(lagappioer) if e(sample)
foreach x in lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnland_GDP  laglnrkna_GDP laglnlowskill_GDP lagappioer {
gen `x'b2=b`x'*(s`x'/slngvcob_EORA)
}
drop blag* slag* bln* sln* slngvc* 

xtreg lnimports lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnland_GDP  laglnrkna_GDP laglnlowskill_GDP lagappioer dedum* , be  
outreg2  using "table_backwardforwardlevels_country.xls", excel dec(3) append	
gen blagtar_wmean_mfg=_b[lagtar_wmean_mfg]
gen blaglnfdi_in_flow=_b[laglnfdi_in_flow] 
gen blnsumdist=_b[lnsumdist] 
gen blagstability_est=_b[lagstability_est] 
gen blaglnvamfg=_b[laglnvamfg] 
gen blagrents_resources=_b[lagrents_resources] 
gen blaglnland_GDP=_b[laglnland_GDP] 
gen blaglnrkna_GDP=_b[laglnrkna_GDP] 
gen blaglnlowskill_GDP=_b[laglnlowskill_GDP] 
gen blagappioer=_b[lagappioer]
egen slnimports=sd(lnimports) if e(sample)
egen slagtar_wmean_mfg=sd(lagtar_wmean_mfg) if e(sample)
egen slaglnfdi_in_flow=sd(laglnfdi_in_flow) if e(sample)
egen slnsumdist=sd(lnsumdist) if e(sample)
egen slagstability_est=sd(lagstability_est) if e(sample)
egen slaglnvamfg=sd(laglnvamfg) if e(sample)
egen slagrents_resources=sd(lagrents_resources) if e(sample)
egen slaglnland_GDP=sd(laglnland_GDP) if e(sample) 
egen slaglnrkna_GDP=sd(laglnrkna_GDP) if e(sample) 
egen slaglnlowskill_GDP=sd(laglnlowskill_GDP) if e(sample) 
egen slagappioer=sd(lagappioer) if e(sample)
foreach x in lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnland_GDP  laglnrkna_GDP laglnlowskill_GDP lagappioer {
gen `x'b3=b`x'*(s`x'/slnimports)
}
drop blag* slag* bln* sln* slnimp* 

xtreg lngvcef_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnland_GDP  laglnrkna_GDP laglnlowskill_GDP lagappioer dedum* , be  
outreg2  using "table_backwardforwardlevels_country.xls", excel dec(3) append	
gen blagtar_wmean_mfg=_b[lagtar_wmean_mfg]
gen blaglnfdi_in_flow=_b[laglnfdi_in_flow] 
gen blnsumdist=_b[lnsumdist] 
gen blagstability_est=_b[lagstability_est] 
gen blaglnvamfg=_b[laglnvamfg] 
gen blagrents_resources=_b[lagrents_resources] 
gen blaglnland_GDP=_b[laglnland_GDP] 
gen blaglnrkna_GDP=_b[laglnrkna_GDP] 
gen blaglnlowskill_GDP=_b[laglnlowskill_GDP] 
gen blagappioer=_b[lagappioer]
egen slngvcef_EORA=sd(lngvcef_EORA) if e(sample)
egen slagtar_wmean_mfg=sd(lagtar_wmean_mfg) if e(sample)
egen slaglnfdi_in_flow=sd(laglnfdi_in_flow) if e(sample)
egen slnsumdist=sd(lnsumdist) if e(sample)
egen slagstability_est=sd(lagstability_est) if e(sample)
egen slaglnvamfg=sd(laglnvamfg) if e(sample)
egen slagrents_resources=sd(lagrents_resources) if e(sample)
egen slaglnland_GDP=sd(laglnland_GDP) if e(sample) 
egen slaglnrkna_GDP=sd(laglnrkna_GDP) if e(sample) 
egen slaglnlowskill_GDP=sd(laglnlowskill_GDP) if e(sample) 
egen slagappioer=sd(lagappioer) if e(sample)
foreach x in lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnland_GDP  laglnrkna_GDP laglnlowskill_GDP lagappioer {
gen `x'b4=b`x'*(s`x'/slngvcef_EORA)
}
drop blag* slag* bln* sln* slngvc* 

xtreg lngvcof_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnland_GDP  laglnrkna_GDP laglnlowskill_GDP lagappioer dedum* , be  
outreg2  using "table_backwardforwardlevels_country.xls", excel dec(3) append	
gen blagtar_wmean_mfg=_b[lagtar_wmean_mfg]
gen blaglnfdi_in_flow=_b[laglnfdi_in_flow] 
gen blnsumdist=_b[lnsumdist] 
gen blagstability_est=_b[lagstability_est] 
gen blaglnvamfg=_b[laglnvamfg] 
gen blagrents_resources=_b[lagrents_resources] 
gen blaglnland_GDP=_b[laglnland_GDP] 
gen blaglnrkna_GDP=_b[laglnrkna_GDP] 
gen blaglnlowskill_GDP=_b[laglnlowskill_GDP] 
gen blagappioer=_b[lagappioer]
egen slngvcof_EORA=sd(lngvcof_EORA) if e(sample)
egen slagtar_wmean_mfg=sd(lagtar_wmean_mfg) if e(sample)
egen slaglnfdi_in_flow=sd(laglnfdi_in_flow) if e(sample)
egen slnsumdist=sd(lnsumdist) if e(sample)
egen slagstability_est=sd(lagstability_est) if e(sample)
egen slaglnvamfg=sd(laglnvamfg) if e(sample)
egen slagrents_resources=sd(lagrents_resources) if e(sample)
egen slaglnland_GDP=sd(laglnland_GDP) if e(sample) 
egen slaglnrkna_GDP=sd(laglnrkna_GDP) if e(sample) 
egen slaglnlowskill_GDP=sd(laglnlowskill_GDP) if e(sample) 
egen slagappioer=sd(lagappioer) if e(sample)
foreach x in lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnland_GDP  laglnrkna_GDP laglnlowskill_GDP lagappioer {
gen `x'b5=b`x'*(s`x'/slngvcof_EORA)
}
drop blag* slag* bln* sln* slngvc* 

xtreg lnexports lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnland_GDP  laglnrkna_GDP laglnlowskill_GDP lagappioer dedum* , be  
outreg2  using "table_backwardforwardlevels_country.xls", excel dec(3) append	
gen blagtar_wmean_mfg=_b[lagtar_wmean_mfg]
gen blaglnfdi_in_flow=_b[laglnfdi_in_flow] 
gen blnsumdist=_b[lnsumdist] 
gen blagstability_est=_b[lagstability_est] 
gen blaglnvamfg=_b[laglnvamfg] 
gen blagrents_resources=_b[lagrents_resources] 
gen blaglnland_GDP=_b[laglnland_GDP] 
gen blaglnrkna_GDP=_b[laglnrkna_GDP] 
gen blaglnlowskill_GDP=_b[laglnlowskill_GDP] 
gen blagappioer=_b[lagappioer]
egen slnexports=sd(lnexports) if e(sample)
egen slagtar_wmean_mfg=sd(lagtar_wmean_mfg) if e(sample)
egen slaglnfdi_in_flow=sd(laglnfdi_in_flow) if e(sample)
egen slnsumdist=sd(lnsumdist) if e(sample)
egen slagstability_est=sd(lagstability_est) if e(sample)
egen slaglnvamfg=sd(laglnvamfg) if e(sample)
egen slagrents_resources=sd(lagrents_resources) if e(sample)
egen slaglnland_GDP=sd(laglnland_GDP) if e(sample) 
egen slaglnrkna_GDP=sd(laglnrkna_GDP) if e(sample) 
egen slaglnlowskill_GDP=sd(laglnlowskill_GDP) if e(sample) 
egen slagappioer=sd(lagappioer) if e(sample)
foreach x in lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnland_GDP  laglnrkna_GDP laglnlowskill_GDP lagappioer {
gen `x'b6=b`x'*(s`x'/slnexports)
}
drop blag* slag* bln* sln* slnexp* 
preserve
collapse (mean) *b1 *b2 *b3 *b4 *b5 *b6 
save "betacoefficients_table_backwardforwardlevels_country.dta"
restore
drop *b1 *b2 *b3 *b4 *b5 *b6 





